pub struct Message<T = Value> {
pub msg_id: i64,
pub vt: DateTime<Utc>,
pub enqueued_at: DateTime<Utc>,
pub read_ct: i32,
pub message: T,
}Expand description
Message struct received from the queue
It is an “envelope” for the message that is stored in the queue. It contains both the message body but also metadata about the message.
Fields
msg_id: i64unique identifier for the message
vt: DateTime<Utc>“visibility time”. The UTC timestamp at which the message will be available for reading again.
enqueued_at: DateTime<Utc>UTC timestamp that the message was sent to the queue
read_ct: i32The number of times the message has been read. Increments on read.
message: TThe message body.